@@ -20,7 +20,7 @@
 #include "StopWatch.h"
 
 #include <Lum/Base/String.h>
-
+#include <iostream>
 #include "config.h"
 
 static Lum::OS::Display::FontType fontType  = Lum::OS::Display::fontTypeFixed;
@@ -93,13 +93,15 @@ Lum::OS::Font* StopWatch::FindFont(size_t& digitWidth, size_t& divWidth)
 #if defined(HAVE_LIB_HILDON)
   if (height==338 && width==768) {
     fontSize=271;
+    std::cout << "Hildon shortcut for " << fontSize << " " << width << "x" << height << std::endl;
   }
   else if (height==338 && width==666) {
     fontSize=236;
+    std::cout << "Hildon shortcut for " << fontSize << " " << width << "x" << height << std::endl;
   }
 #endif
 
-  while (true) {
+  while (fontSize>minFont->pixelHeight) {
     Lum::OS::FontRef tmpFont;
     size_t           w=0;
 
@@ -115,6 +117,7 @@ Lum::OS::Font* StopWatch::FindFont(size_t& digitWidth, size_t& divWidth)
 
       if (3*digitWidth+divWidth+2*digitWidth<=width &&
           tmpFont->pixelHeight<=height) {
+        std::cout << "Matching FontSize for "<< width << "x" << height << ": " << fontSize << std::endl;
         return tmpFont;
       }
     }
@@ -122,6 +125,8 @@ Lum::OS::Font* StopWatch::FindFont(size_t& digitWidth, size_t& divWidth)
     fontSize--;
   };
 
+  std::cout << "Fallback FontSize: " << fontSize << std::endl;
+
   digitWidth=minDigitWidth;
   divWidth=minDivWidth;
 
